diff --git src/file/CMakeLists.txt src/file/CMakeLists.txt
index 49a34dd..262e45f 100644
--- src/file/CMakeLists.txt
+++ src/file/CMakeLists.txt
@@ -59,6 +59,12 @@ target_link_libraries(baloo_file
     balooxapian
 )
 
+if (APPLE)
+    set_target_properties(baloo_file PROPERTIES MACOSX_BUNDLE_INFO_PLIST ${CMAKE_CURRENT_SOURCE_DIR}/Info.plist.template)
+    set_target_properties(baloo_file PROPERTIES MACOSX_BUNDLE_GUI_IDENTIFIER "org.kde.baloo.file")
+    set_target_properties(baloo_file PROPERTIES MACOSX_BUNDLE_BUNDLE_NAME "KDE Baloo File Daemon service")
+endif (APPLE)
+
 install(TARGETS baloo_file ${INSTALL_TARGETS_DEFAULT_ARGS})
 install(FILES baloo_file.desktop DESTINATION ${AUTOSTART_INSTALL_DIR})
 install(FILES org.kde.baloo.file.indexer.xml DESTINATION ${DBUS_INTERFACES_INSTALL_DIR})
diff --git src/file/Info.plist.template src/file/Info.plist.template
new file mode 100644
index 0000000..c39ddb9
--- /dev/null
+++ src/file/Info.plist.template
@@ -0,0 +1,36 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+    <key>CFBundleDevelopmentRegion</key>
+    <string>English</string>
+    <key>CFBundleExecutable</key>
+    <string>${MACOSX_BUNDLE_EXECUTABLE_NAME}</string>
+    <key>CFBundleGetInfoString</key>
+    <string>${MACOSX_BUNDLE_INFO_STRING}</string>
+    <key>CFBundleIconFile</key>
+    <string>${MACOSX_BUNDLE_ICON_FILE}</string>
+    <key>CFBundleIdentifier</key>
+    <string>${MACOSX_BUNDLE_GUI_IDENTIFIER}</string>
+    <key>CFBundleInfoDictionaryVersion</key>
+    <string>6.0</string>
+    <key>CFBundleLongVersionString</key>
+    <string>${MACOSX_BUNDLE_LONG_VERSION_STRING}</string>
+    <key>CFBundleName</key>
+    <string>${MACOSX_BUNDLE_BUNDLE_NAME}</string>
+    <key>CFBundlePackageType</key>
+    <string>APPL</string>
+    <key>CFBundleShortVersionString</key>
+    <string>${MACOSX_BUNDLE_SHORT_VERSION_STRING}</string>
+    <key>CFBundleVersion</key>
+    <string>${MACOSX_BUNDLE_BUNDLE_VERSION}</string>
+    <key>CSResourcesFileMapped</key>
+    <true/>
+    <key>LSRequiresCarbon</key>
+    <true/>
+    <key>LSUIElement</key>
+    <string>1</string>
+    <key>NSHumanReadableCopyright</key>
+    <string>${MACOSX_BUNDLE_COPYRIGHT}</string>
+</dict>
+</plist>
diff --git src/file/extractor/CMakeLists.txt src/file/extractor/CMakeLists.txt
index 31efc6a..7cb0596 100644
--- src/file/extractor/CMakeLists.txt
+++ src/file/extractor/CMakeLists.txt
@@ -11,7 +11,7 @@ set(EXTRACTOR_SRCS
   ../fileexcludefilters.cpp
 )
 
-kde4_add_executable(baloo_file_extractor ${EXTRACTOR_SRCS})
+kde4_add_executable(baloo_file_extractor NOGUI ${EXTRACTOR_SRCS})
 
 target_link_libraries(baloo_file_extractor
   ${QT_QTSQL_LIBRARY}
diff --git src/file/extractor/main.cpp src/file/extractor/main.cpp
index 4be2c24..30c26d8 100644
--- src/file/extractor/main.cpp
+++ src/file/extractor/main.cpp
@@ -71,7 +71,7 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    QApplication app(argc, argv);
+    QApplication app(argc, argv, false);
     KComponentData data(aboutData, KComponentData::RegisterAsMainComponent);
 
     Baloo::App appObject;
diff --git src/file/priority.cpp src/file/priority.cpp
index 1c4e568..a657d32 100644
--- src/file/priority.cpp
+++ src/file/priority.cpp
@@ -75,6 +75,12 @@ bool lowerIOPriority()
         }
     }
     return true;
+#elif defined(Q_OS_MAC)
+	if (setiopolicy_np( IOPOL_TYPE_DISK, IOPOL_SCOPE_PROCESS, IOPOL_THROTTLE ) < 0 ) {
+		qDebug( "cannot set io scheduling to IOPOL_THROTTLE (%s).\n", strerror(errno) );
+		return false;
+	}
+	return true;
 #else
     return false;
 #endif
diff --git src/pim/agent/CMakeLists.txt src/pim/agent/CMakeLists.txt
index cd19027..6fc7548 100644
--- src/pim/agent/CMakeLists.txt
+++ src/pim/agent/CMakeLists.txt
@@ -33,6 +33,12 @@ target_link_libraries(akonadi_baloo_indexer
     balooxapian
 )
 
+if (APPLE)
+    set_target_properties(akonadi_baloo_indexer PROPERTIES MACOSX_BUNDLE_INFO_PLIST ${CMAKE_CURRENT_SOURCE_DIR}/Info.plist.template)
+    set_target_properties(akonadi_baloo_indexer PROPERTIES MACOSX_BUNDLE_GUI_IDENTIFIER "org.kde.akonadi.baloo.indexer")
+    set_target_properties(akonadi_baloo_indexer PROPERTIES MACOSX_BUNDLE_BUNDLE_NAME "KDE Akonadi Baloo Indexing Agent")
+endif (APPLE)
+
 install(TARGETS akonadi_baloo_indexer ${INSTALL_TARGETS_DEFAULT_ARGS})
 install(FILES akonadibalooindexingagent.desktop
         DESTINATION "${CMAKE_INSTALL_PREFIX}/share/akonadi/agents")
diff --git src/pim/agent/Info.plist.template src/pim/agent/Info.plist.template
new file mode 100644
index 0000000..c39ddb9
--- /dev/null
+++ src/pim/agent/Info.plist.template
@@ -0,0 +1,36 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+    <key>CFBundleDevelopmentRegion</key>
+    <string>English</string>
+    <key>CFBundleExecutable</key>
+    <string>${MACOSX_BUNDLE_EXECUTABLE_NAME}</string>
+    <key>CFBundleGetInfoString</key>
+    <string>${MACOSX_BUNDLE_INFO_STRING}</string>
+    <key>CFBundleIconFile</key>
+    <string>${MACOSX_BUNDLE_ICON_FILE}</string>
+    <key>CFBundleIdentifier</key>
+    <string>${MACOSX_BUNDLE_GUI_IDENTIFIER}</string>
+    <key>CFBundleInfoDictionaryVersion</key>
+    <string>6.0</string>
+    <key>CFBundleLongVersionString</key>
+    <string>${MACOSX_BUNDLE_LONG_VERSION_STRING}</string>
+    <key>CFBundleName</key>
+    <string>${MACOSX_BUNDLE_BUNDLE_NAME}</string>
+    <key>CFBundlePackageType</key>
+    <string>APPL</string>
+    <key>CFBundleShortVersionString</key>
+    <string>${MACOSX_BUNDLE_SHORT_VERSION_STRING}</string>
+    <key>CFBundleVersion</key>
+    <string>${MACOSX_BUNDLE_BUNDLE_VERSION}</string>
+    <key>CSResourcesFileMapped</key>
+    <true/>
+    <key>LSRequiresCarbon</key>
+    <true/>
+    <key>LSUIElement</key>
+    <string>1</string>
+    <key>NSHumanReadableCopyright</key>
+    <string>${MACOSX_BUNDLE_COPYRIGHT}</string>
+</dict>
+</plist>
